"use strict";
/**
 * Layouts - Column
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Column = void 0;
const filter_js_1 = require("../../utils/filter/filter.js");
const string_js_1 = require("../../utils/string/string.js");
const object_js_1 = require("../../utils/object/object.js");
/**
 * Output column wrapper
 *
 * @param {ColumnProps} props
 * @return {string[]}
 */
const Column = (props) => {
    /* Fallback output */
    const fallback = [];
    /* Props must be object */
    if (!(0, object_js_1.isObjectStrict)(props)) {
        return fallback;
    }
    props = (0, filter_js_1.applyFilters)('columnProps', props, { renderType: 'column' });
    /* Filtered props must be object */
    if (!(0, object_js_1.isObjectStrict)(props)) {
        return fallback;
    }
    const { args } = props;
    const { tag = 'div', classes = '', style = '', attr = '' } = (0, object_js_1.isObjectStrict)(args) ? args : {};
    /* Tag required */
    if (!(0, string_js_1.isStringStrict)(tag)) {
        return fallback;
    }
    /* Style */
    let styles = '';
    if ((0, string_js_1.isStringStrict)(style)) {
        styles = ` style="${style}"`;
    }
    /* Attributes */
    let attrs = '';
    if ((0, string_js_1.isStringStrict)(classes)) {
        attrs += ` class="${classes}"`;
    }
    if ((0, string_js_1.isStringStrict)(attr)) {
        attrs += ` ${attr}`;
    }
    /* Output */
    return [
        `<${tag}${attrs}${styles}>`,
        `</${tag}>`
    ];
};
exports.Column = Column;
