"use strict";
/**
 * Layouts - Container
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Container = void 0;
const filter_js_1 = require("../../utils/filter/filter.js");
const object_js_1 = require("../../utils/object/object.js");
const string_js_1 = require("../../utils/string/string.js");
/**
 * Output container wrapper
 *
 * @param {ContainerProps} props
 * @return {string[]}
 */
const Container = (props) => {
    /* Fallback output */
    const fallback = [];
    /* Props must be object */
    if (!(0, object_js_1.isObjectStrict)(props)) {
        return fallback;
    }
    props = (0, filter_js_1.applyFilters)('containerProps', props, { renderType: 'container' });
    /* Filtered props must be object */
    if (!(0, object_js_1.isObjectStrict)(props)) {
        return fallback;
    }
    let { args } = props;
    args = (0, object_js_1.isObjectStrict)(args) ? args : {};
    const { tag = 'div', layoutClasses = '', classes = '', style = '', attr = '', nest = false } = args;
    /* Tag required */
    if (!(0, string_js_1.isStringStrict)(tag)) {
        return fallback;
    }
    /* Semantically specific */
    const isSemanticParent = ['ul', 'ol', 'dl', 'figure'].includes(tag);
    /* Classes */
    const hasLayoutClasses = (0, string_js_1.isStringStrict)(layoutClasses);
    const hasClasses = (0, string_js_1.isStringStrict)(classes);
    /* Attributes */
    const attrs = [];
    const innerAttrs = [];
    /* Nest check */
    const isNested = nest && hasLayoutClasses;
    const isNestedSemanticParent = isSemanticParent && isNested;
    /* Classes */
    const innerClassesArr = [];
    if (isNested && hasLayoutClasses) {
        innerClassesArr.push(layoutClasses);
    }
    const outerClassesArr = [];
    if (isNested && hasClasses) {
        outerClassesArr.push(classes);
    }
    if (!isNested && hasClasses) {
        outerClassesArr.push(classes);
    }
    if (!isNested && hasLayoutClasses) {
        outerClassesArr.push(layoutClasses);
    }
    if (outerClassesArr.length > 0) {
        attrs.push(`class="${outerClassesArr.join(' ')}"`);
    }
    if (innerClassesArr.length > 0) {
        innerAttrs.push(`class="${innerClassesArr.join(' ')}"`);
    }
    /* Style and more attributes */
    const att = isNestedSemanticParent ? innerAttrs : attrs;
    if ((0, string_js_1.isStringStrict)(attr)) {
        att.push(attr);
    }
    if ((0, string_js_1.isStringStrict)(style)) {
        att.push(`style="${style}"`);
    }
    /* Output */
    let outerTag = tag;
    let innerTag = '';
    if (isNested) {
        outerTag = isSemanticParent ? 'div' : tag;
        innerTag = isSemanticParent ? tag : 'div';
    }
    let start = `<${outerTag}${(attrs.length > 0) ? ` ${attrs.join(' ')}` : ''}>`;
    let end = `</${outerTag}>`;
    if (innerTag !== '') {
        start = `${start}<${innerTag}${(innerAttrs.length > 0) ? ` ${innerAttrs.join(' ')}` : ''}>`;
        end = `</${innerTag}>${end}`;
    }
    return [start, end];
};
exports.Container = Container;
