"use strict";
/**
 * Local - Data Normal
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.undefineProps = exports.resolveInternalLinks = void 0;
/* Imports */
const array_js_1 = require("../utils/array/array.js");
const string_js_1 = require("../utils/string/string.js");
const object_js_1 = require("../utils/object/object.js");
const objectUtils_js_1 = require("../utils/object/objectUtils.js");
const function_js_1 = require("../utils/function/function.js");
/**
 * Recursively set internal props from outer data
 *
 * @param {object} data
 * @param {object} currentData
 * @param {string[]} [props]
 * @param {function} [filterValue]
 * @return {void}
 */
const resolveInternalLinks = (data, currentData, props = ['internalLink'], filterValue) => {
    if (!(0, object_js_1.isObject)(data) || !(0, object_js_1.isObject)(currentData) || !(0, array_js_1.isArray)(props)) {
        return;
    }
    (0, objectUtils_js_1.getObjectKeys)(currentData).forEach((prop) => {
        const value = currentData[prop];
        if (props.includes(prop.toString())) {
            let v;
            if ((0, array_js_1.isArray)(value)) {
                v = value.map((k) => data[k]);
            }
            if ((0, string_js_1.isString)(value)) {
                v = data[value];
            }
            if ((0, function_js_1.isFunction)(filterValue)) {
                v = filterValue(prop, v);
            }
            currentData[prop] = v;
        }
        else if ((0, object_js_1.isObject)(value)) {
            resolveInternalLinks(data, value, props, filterValue);
        }
    });
};
exports.resolveInternalLinks = resolveInternalLinks;
/**
 * Set property in object or array of objects to undefined
 *
 * @param {object|object[]} obj
 * @param {string[]} props
 * @return {object|object[]}
 */
const undefineProps = (obj, props = []) => {
    if (!(0, object_js_1.isObject)(obj)) {
        return obj;
    }
    const clone = structuredClone(obj);
    (0, objectUtils_js_1.getObjectKeys)(clone).forEach((prop) => {
        const value = clone[prop];
        if (props.includes(prop.toString())) {
            // @ts-expect-error: Type 'undefined' is not assignable to type 'T[keyof T]'
            clone[prop] = undefined;
        }
        else if ((0, object_js_1.isObject)(value)) {
            undefineProps(value, props);
        }
    });
    return clone;
};
exports.undefineProps = undefineProps;
