"use strict";
/**
 * Objects - Form
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Form = void 0;
const uuid_1 = require("uuid");
const filter_js_1 = require("../../utils/filter/filter.js");
const string_js_1 = require("../../utils/string/string.js");
const object_js_1 = require("../../utils/object/object.js");
const store_js_1 = require("../../store/store.js");
const scriptStyle_js_1 = require("../../utils/scriptStyle/scriptStyle.js");
const config_js_1 = require("../../config/config.js");
/**
 * Output form wrapper
 *
 * @param {FormProps} props
 * @return {string[]} HTMLFormElement
 */
const Form = (props) => {
    /* Fallback output */
    const fallback = [];
    /* Props must be object */
    if (!(0, object_js_1.isObjectStrict)(props)) {
        return fallback;
    }
    props = (0, filter_js_1.applyFilters)('formProps', props, { renderType: 'form' });
    /* Filtered props must be object */
    if (!(0, object_js_1.isObjectStrict)(props)) {
        return fallback;
    }
    const { args } = props;
    const { id = '', action = 'sendForm', subject = '', toEmail = '', senderEmail = '', submitLabel = 'Send', successTitle = '', successText = '', errorTitle = '', errorText = '', errorSummary = '', errorResult = '', successResult = '', formClasses = '', formAttr = '', fieldsClasses = '', fieldsAttr = '', submitFieldClasses = '', submitClasses = '', submitAttr = '', submitLoader = '', honeypotFieldClasses = '', honeypotLabelClasses = '', honeypotClasses = '' } = (0, object_js_1.isObjectStrict)(args) ? args : {};
    /* Id required */
    if (!(0, string_js_1.isStringStrict)(id)) {
        return fallback;
    }
    /* Add to form meta data */
    const meta = {};
    if ((0, string_js_1.isStringStrict)(subject)) {
        meta.subject = subject;
    }
    if ((0, string_js_1.isStringStrict)(toEmail)) {
        meta.toEmail = toEmail;
    }
    if ((0, string_js_1.isStringStrict)(senderEmail)) {
        meta.senderEmail = senderEmail;
    }
    (0, store_js_1.setStoreItem)('formMeta', meta, id);
    /* Add to script data */
    const scriptMeta = {};
    if ((0, string_js_1.isStringStrict)(successTitle)) {
        scriptMeta.successMessage = {
            primary: successTitle,
            secondary: successText
        };
    }
    if ((0, string_js_1.isStringStrict)(errorTitle)) {
        scriptMeta.errorMessage = {
            primary: errorTitle,
            secondary: errorText
        };
    }
    if (!(0, object_js_1.isObjectStrict)(scriptStyle_js_1.scripts.meta.forms)) {
        scriptStyle_js_1.scripts.meta.forms = {};
    }
    scriptStyle_js_1.scripts.meta.forms[id] = {
        url: '/ajax/',
        ...scriptMeta
    };
    /* Honeypot */
    const honeypotId = (0, uuid_1.v4)();
    const honeypotName = `${config_js_1.config.namespace}_asi`;
    const honeypot = `
    <div${(0, string_js_1.isStringStrict)(honeypotFieldClasses) ? ` class="${honeypotFieldClasses}"` : ''} data-form-asi>
      <label${(0, string_js_1.isStringStrict)(honeypotLabelClasses) ? ` class="${honeypotLabelClasses}"` : ''} for="${honeypotId}">Website</label>
      <input${(0, string_js_1.isStringStrict)(honeypotClasses) ? ` class="${honeypotClasses}"` : ''} type="url" name="${honeypotName}" id="${honeypotId}" autocomplete="off">
    </div>
  `;
    /* Output */
    return [`
    <form${(0, string_js_1.isStringStrict)(formClasses) ? ` class="${formClasses}"` : ''} id="${id}" data-form-action="${action}"${(0, string_js_1.isStringStrict)(formAttr) ? ` ${formAttr}` : ''} novalidate>
      <div${(0, string_js_1.isStringStrict)(fieldsClasses) ? ` class="${fieldsClasses}"` : ''}${(0, string_js_1.isStringStrict)(fieldsAttr) ? ` ${fieldsAttr}` : ''}>
        ${errorSummary}`,
        `${honeypot}
        ${errorResult}
        <div${(0, string_js_1.isStringStrict)(submitFieldClasses) ? ` class="${submitFieldClasses}"` : ''} data-form-submit>
          <button${(0, string_js_1.isStringStrict)(submitClasses) ? ` class="${submitClasses}"` : ''}${(0, string_js_1.isStringStrict)(submitAttr) ? ` ${submitAttr}` : ''} type="submit">
            ${submitLoader}
            <span>${submitLabel}</span>
          </button>
        </div>
        ${successResult}
      </div>
    </form>
  `];
};
exports.Form = Form;
