"use strict";
/**
 * Serverless - Preview
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Preview = void 0;
const string_js_1 = require("../../utils/string/string.js");
const object_js_1 = require("../../utils/object/object.js");
const function_js_1 = require("../../utils/function/function.js");
const render_js_1 = require("../../render/render.js");
/**
 * Output preview from contentful or wordpress
 *
 * @param {ServerlessContext} context
 * @param {ServerlessSetup} setupServerless
 * @param {function} getData - getAllContentfulData | getAllWordPressData
 * @return {Promise<Response>} Response
 */
const Preview = async (context, setupServerless, getData) => {
    /* Params */
    const { request, next } = context;
    const { searchParams } = new URL(request.url);
    const contentType = searchParams.get('content_type');
    const id = searchParams.get('preview');
    /* Preview id and content type required */
    if (!(0, string_js_1.isStringStrict)(id) || !(0, string_js_1.isStringStrict)(contentType)) {
        return next(); // eslint-disable-line @typescript-eslint/return-await
    }
    /* Setup */
    setupServerless(context);
    /* Data params */
    const previewData = { id, contentType };
    /* Output */
    const data = await (0, render_js_1.render)({
        previewData,
        allData: await getData({
            previewData
        })
    });
    let html = '';
    let status = 200;
    if ((0, object_js_1.isObjectStrict)(data)) {
        html = data.output;
    }
    const isEmpty = html === '';
    if (isEmpty) {
        status = 404;
    }
    if (isEmpty && (0, function_js_1.isFunction)(render_js_1.renderHttpError)) {
        html = await (0, render_js_1.renderHttpError)({ code: status });
    }
    return new Response(html, {
        status,
        headers: {
            'Content-Type': 'text/html;charset=UTF-8'
        }
    });
};
exports.Preview = Preview;
