"use strict";
/**
 * Serverless
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.setServerless = exports.serverlessActions = exports.serverlessApiKeys = exports.serverlessRoutes = exports.serverlessDir = void 0;
const string_js_1 = require("../utils/string/string.js");
const object_js_1 = require("../utils/object/object.js");
/**
 * Directory to write serverless files to
 *
 * @type {string}
 */
let serverlessDir = 'functions';
exports.serverlessDir = serverlessDir;
/**
 * Serverless routes to create files for
 *
 * @type {ServerlessRoutes}
 */
let serverlessRoutes = {
    reload: []
};
exports.serverlessRoutes = serverlessRoutes;
/**
 * Api keys for use in serverless functions
 *
 * @type {GenericStrings}
 */
let serverlessApiKeys = {
    smtp2go: ''
};
exports.serverlessApiKeys = serverlessApiKeys;
/**
 * Actions to use in serverless functions
 *
 * @type {ServerlessActions}
 */
let serverlessActions = {};
exports.serverlessActions = serverlessActions;
/**
 * Set serverless options
 *
 * @param {ServerlessArgs} args
 * @param {string} [dir]
 */
const setServerless = (args, dir = 'functions') => {
    if (!(0, object_js_1.isObjectStrict)(args)) {
        return false;
    }
    const { actions, routes, apiKeys } = args;
    if ((0, object_js_1.isObjectStrict)(actions)) {
        exports.serverlessActions = serverlessActions = { ...actions };
    }
    if ((0, object_js_1.isObjectStrict)(routes)) {
        exports.serverlessRoutes = serverlessRoutes = {
            ...{ reload: [] },
            ...routes
        };
    }
    if ((0, object_js_1.isObjectStrict)(apiKeys)) {
        exports.serverlessApiKeys = serverlessApiKeys = {
            ...{ smtp2go: '' },
            ...apiKeys
        };
    }
    if ((0, string_js_1.isStringStrict)(dir)) {
        exports.serverlessDir = serverlessDir = dir;
    }
    return true;
};
exports.setServerless = setServerless;
