"use strict";
/**
 * Utils - Excerpt
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getExcerpt = void 0;
const object_js_1 = require("../object/object.js");
const string_js_1 = require("../string/string.js");
const shortcode_js_1 = require("../shortcode/shortcode.js");
/**
 * Get words from object or array of content
 *
 * @private
 * @param {ExcerptContentWordArgs} args
 * @return {string[]}
 */
const getContentWords = (args) => {
    const { content, prop, limit = 25 } = args;
    let { _words = [] } = args;
    const max = limit + 1;
    const wordsLen = _words.length;
    if ((0, object_js_1.isObject)(content) && wordsLen < max) {
        const addMax = max - wordsLen;
        for (const [key, value] of Object.entries(content)) {
            if (key === prop && (0, string_js_1.isStringStrict)(value)) {
                const val = (0, shortcode_js_1.stripShortcodes)(value);
                if ((0, string_js_1.isStringStrict)(val)) {
                    let valArr = val.split(' ');
                    if (valArr.length > addMax) {
                        valArr = valArr.slice(0, addMax);
                    }
                    _words = _words.concat(valArr);
                }
            }
            if ((0, object_js_1.isObject)(value)) {
                _words = getContentWords({
                    content: value,
                    prop,
                    limit,
                    _words
                });
            }
        }
    }
    return _words;
};
/**
 * Get exercept from content and limit by words
 *
 * @param {ExcerptArgs} args
 * @return {string}
 */
const getExcerpt = (args) => {
    const { excerpt = '', content = undefined, prop = 'content', limit = 25, limitExcerpt = false, more = '&hellip;' } = (0, object_js_1.isObjectStrict)(args) ? args : {};
    let output = '';
    if ((0, string_js_1.isStringStrict)(excerpt)) {
        output = excerpt;
        if (limitExcerpt) {
            let excerptArr = excerpt.split(' ');
            const excerptLen = excerptArr.length;
            if (excerptLen > limit) {
                excerptArr = excerptArr.slice(0, limit);
                output = `${excerptArr.join(' ')}${more}`;
            }
        }
    }
    else {
        const words = getContentWords({
            content,
            prop,
            limit
        });
        const wordsLen = words.length;
        if (wordsLen > 0) {
            if (wordsLen > limit && more !== '') {
                words.pop();
            }
            output = `${words.join(' ')}${wordsLen > limit ? more : ''}`;
        }
    }
    return output;
};
exports.getExcerpt = getExcerpt;
