"use strict";
/**
 * Utils - Paths
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFilePaths = void 0;
/* Imports */
const promises_1 = require("node:fs/promises");
const node_path_1 = require("node:path");
const string_js_1 = require("../string/string.js");
/**
 * Recurse directory to get all file paths in it
 *
 * @param {string} dir
 * @yield {string[]}
 */
const getFilePaths = async function* (dir) {
    if (!(0, string_js_1.isStringStrict)(dir)) {
        throw new Error('No directory provided');
    }
    const files = await (0, promises_1.readdir)(dir, { withFileTypes: true });
    for (const file of files) {
        if (file.isDirectory()) {
            yield* getFilePaths((0, node_path_1.join)(dir, file.name));
        }
        else {
            yield (0, node_path_1.join)(dir, file.name);
        }
    }
};
exports.getFilePaths = getFilePaths;
