/**
 * Utils - Filter
 */
import type { Filters, FilterMap, FilterReturnType } from './filterTypes.js';
/**
 * Store filter callbacks by name
 *
 * @type {FilterMap}
 */
declare let filters: FilterMap;
/**
 * Add filter to filters map
 *
 * @param {string} name
 * @param {function} filter
 * @return {boolean}
 */
declare const addFilter: <T extends keyof Filters>(name: T, filter: Filters[T]) => boolean;
/**
 * Remove filter from filters map
 *
 * @param {string} name
 * @param {function} filter
 * @return {boolean}
 */
declare const removeFilter: <T extends keyof Filters>(name: T, filter: Filters[T]) => boolean;
/**
 * Update value from callback return values
 *
 * @param {string} name
 * @param {*} value
 * @param {*} [args]
 * @param {boolean} [isAsync]
 * @return {*}
 */
declare const applyFilters: <T, U, V extends boolean = false>(name: string, value: T, args?: U, isAsync?: V) => FilterReturnType<T, V>;
/**
 * Empty filters map
 *
 * @return {void}
 */
declare const resetFilters: () => void;
/**
 * Fill filters map
 *
 * @param {Filters} args
 * @return {boolean}
 */
declare const setFilters: (args: Partial<Filters>) => boolean;
export { filters, addFilter, removeFilter, applyFilters, resetFilters, setFilters };
