"use strict";
/**
 * Utils - Link Share
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getShareLinks = void 0;
const string_js_1 = require("../string/string.js");
const array_js_1 = require("../array/array.js");
/**
 * Start of share links by platform
 *
 * @type {LinkShare}
 */
const shareLinks = {
    Facebook: 'https://www.facebook.com/sharer.php?u=',
    X: 'https://twitter.com/intent/tweet?url=',
    LinkedIn: 'https://www.linkedin.com/shareArticle?url=',
    Pinterest: 'https://pinterest.com/pin/create/button/?url=',
    Reddit: 'https://reddit.com/submit?url=',
    Email: ''
};
/**
 * Get social share links
 *
 * @param {string} url
 * @param {string[]} platforms
 * @return {LinkShareReturn[]}
 */
const getShareLinks = (url, platforms, title) => {
    if (!(0, string_js_1.isStringStrict)(url) || !(0, array_js_1.isArrayStrict)(platforms)) {
        return [];
    }
    return platforms.map((platform) => {
        const platformLink = shareLinks[platform];
        let link = (0, string_js_1.isStringStrict)(platformLink) ? `${platformLink}${url}` : '';
        if (platform === 'Email') {
            link = `mailto:?subject=${encodeURIComponent((0, string_js_1.isStringStrict)(title) ? title : 'Check out this article')}&body=${url}`;
        }
        return {
            type: platform,
            link
        };
    });
};
exports.getShareLinks = getShareLinks;
