"use strict";
/**
 * Utils - Path
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPathDepth = exports.getPath = void 0;
/* Imports */
const string_js_1 = require("../string/string.js");
const config_js_1 = require("../../config/config.js");
const store_js_1 = require("../../store/store.js");
const serverless_js_1 = require("../../serverless/serverless.js");
/**
 * Get absolute path to file or file from config
 *
 * @param {string} file
 * @param {string} [type]
 * @return {string}
 */
const getPath = (file = '', type = '') => {
    const root = config_js_1.config.env.dir;
    if (!(0, string_js_1.isStringStrict)(root) || !(0, string_js_1.isStringStrict)(file)) {
        return '';
    }
    let append = file;
    if (type === 'store') {
        const dir = store_js_1.storeDir;
        if ((0, string_js_1.isStringStrict)(dir)) {
            append = `${dir}/${file}.json`;
        }
    }
    if (type === 'serverless') {
        const dir = serverless_js_1.serverlessDir;
        if ((0, string_js_1.isStringStrict)(dir)) {
            append = `${dir}/${file}.js`;
        }
    }
    return `${root}${root.endsWith('/') ? '' : '/'}${append}`;
};
exports.getPath = getPath;
/**
 * Relative ascendent path as string
 *
 * @param {string} path
 * @return {string}
 */
const getPathDepth = (path = '') => {
    if (!(0, string_js_1.isStringStrict)(path)) {
        return '';
    }
    let pathDepth = path.split('/');
    pathDepth.pop();
    pathDepth = pathDepth.map(() => {
        return '../';
    });
    return pathDepth.join('');
};
exports.getPathDepth = getPathDepth;
