/**
 * Utils - Shortcode
 */
import type { Shortcode, Shortcodes, ShortcodesSet } from './shortcodeTypes.js';
/**
 * Shortcode callbacks by name
 *
 * @type {Shortcodes}
 */
declare const shortcodes: Shortcodes;
/**
 * Add shortcode to shortcodes map
 *
 * @param {string} name
 * @param {Shortcode} shortcode
 * @return {boolean}
 */
declare const addShortcode: <T extends Shortcode>(name: string, shortcode: T) => boolean;
/**
 * Remove shortcode from shortcodes map
 *
 * @param {string} name
 * @return {boolean}
 */
declare const removeShortcode: (name: string) => boolean;
/**
 * Transform content string with shortcode callbacks
 *
 * @param {string} content
 * @return {Promise<string>}
 */
declare const doShortcodes: (content: string) => Promise<string>;
/**
 * Empty shortcodes map
 *
 * @return {void}
 */
declare const resetShortcodes: () => void;
/**
 * Fill shortcodes map
 *
 * @param {ShortcodesSet} args
 * @return {boolean}
 */
declare const setShortcodes: <T extends ShortcodesSet>(args: T) => boolean;
/**
 * Remove shortcodes from string
 *
 * @param {string} content
 * @return {string}
 */
declare const stripShortcodes: (content: string) => string;
export { shortcodes, addShortcode, removeShortcode, doShortcodes, resetShortcodes, setShortcodes, stripShortcodes };
