"use strict";
/**
 * Utils - Tag
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.tagExists = exports.getTag = void 0;
const object_js_1 = require("../object/object.js");
const string_js_1 = require("../string/string.js");
const array_js_1 = require("../array/array.js");
/**
 * Get data from metadata object
 *
 * @type {TagGet}
 */
const getTag = (obj, id) => {
    if (!(0, object_js_1.isObjectStrict)(obj) || !(0, string_js_1.isStringStrict)(id)) {
        return;
    }
    const tags = obj.metadata?.tags;
    if (!(0, array_js_1.isArrayStrict)(tags)) {
        return;
    }
    let tagInfo;
    tags.find((tag) => {
        if (!(0, object_js_1.isObjectStrict)(tag)) {
            return false;
        }
        const tagId = tag.id;
        if (tagId === id) {
            tagInfo = {
                id: tagId,
                name: (0, string_js_1.isStringStrict)(tag.name) ? tag.name : ''
            };
            return true;
        }
        return false;
    });
    return tagInfo;
};
exports.getTag = getTag;
/**
 * Check if tag exists in metadata object
 *
 * @type {TagExists}
 */
const tagExists = (obj, id) => {
    const res = getTag(obj, id);
    return res != null;
};
exports.tagExists = tagExists;
