/**
 * Components - Navigation
 */
import type { NavigationProps, Navigation as Navigations, NavigationByLocation, NavigationItem, NavigationItemsById, NavigationBreadcrumbItem, NavigationOutputArgs, NavigationBreadcrumbOutputArgs } from './NavigationTypes.js';
/**
 * Recursively generate navigation output
 */
declare class Navigation {
    #private;
    /**
     * All navigations
     *
     * @type {Navigations[]}
     */
    navigations: Navigations[];
    /**
     * All navigation items
     *
     * @type {NavigationItem[]}
     */
    items: NavigationItem[];
    /**
     * Current link to compare against
     *
     * @type {string}
     */
    currentLink: string;
    /**
     * Current content type(s) to compare against
     *
     * @type {string[]}
     */
    currentType: string[];
    /**
     * Initialize success
     *
     * @type {boolean}
     */
    init: boolean;
    /**
     * Set properties and initialize
     *
     * @param {NavigationProps} props
     */
    constructor(props: NavigationProps);
    /**
     * Return navigation html output
     *
     * @param {string} location
     * @param {NavigationOutputArgs} args
     * @param {number} maxDepth
     * @return {string} HTMLUListElement
     */
    getOutput(location?: string, args?: NavigationOutputArgs, maxDepth?: number): string;
    /**
     * Return breadcrumbs html output
     *
     * @param {NavigationBreadcrumbItem[]} items
     * @param {string} current
     * @param {NavigationBreadcrumbOutputArgs} [args]
     * @return {string} HTMLOListElement
     */
    getBreadcrumbs(items: NavigationBreadcrumbItem[], current?: string, args?: NavigationBreadcrumbOutputArgs): string;
    /**
     * Return object of items stored by id
     *
     * @return {NavigationItemsById}
     */
    getItemsById(): NavigationItemsById;
    /**
     * Return object of navigations stored by location
     *
     * @return {NavigationByLocation}
     */
    getNavigationsByLocation(): NavigationByLocation;
}
export { Navigation };
