/**
 * Render
 */
import type { RenderContentArgs, RenderItemArgs, RenderItemReturn, RenderArgs, RenderReturn, RenderFunctions, RenderLayout, RenderHttpError, RenderNavigations, RenderFunctionsArgs } from './renderTypes.js';
import type { HtmlString } from '../global/globalTypes.js';
/**
 * Output elements in render content
 *
 * @type {RenderFunctions}
 */
declare let renderFunctions: RenderFunctions;
/**
 * Output html element
 *
 * @type {RenderLayout}
 */
declare let renderLayout: RenderLayout;
/**
 * Output http error page
 *
 * @type {RenderHttpError}
 */
declare let renderHttpError: RenderHttpError;
/**
 * Navigations output for use in render functions
 *
 * @type {RenderNavigations}
 */
declare let renderNavigations: RenderNavigations;
/**
 * Set content, layout and navigation output functions
 *
 * @param {RenderFunctionsArgs} args
 * @return {boolean}
 */
declare const setRenderFunctions: (args: RenderFunctionsArgs) => boolean;
/**
 * Recurse and output nested content
 *
 * @param {RenderContentArgs} args
 * @param {HtmlString} [_output]
 * @return {Promise<string>}
 */
declare const renderContent: (args: RenderContentArgs, _output?: HtmlString) => Promise<string>;
/**
 * Output single post or page
 *
 * @param {RenderItemArgs} args
 * @return {Promise<RenderItemReturn|null>}
 */
declare const renderItem: (args: RenderItemArgs) => Promise<RenderItemReturn | null>;
/**
 * Loop through all content types to output pages and posts
 *
 * @param {RenderArgs} args
 * @return {Promise<RenderReturn[]|RenderReturn>}
 */
declare const render: (args: RenderArgs) => Promise<RenderReturn[] | RenderReturn>;
export { render, renderItem, renderContent, renderFunctions, renderLayout, renderNavigations, renderHttpError, setRenderFunctions };
