/**
 * Serverless - Preview
 */
import { isStringStrict } from '../../utils/string/string.js';
import { isObjectStrict } from '../../utils/object/object.js';
import { isFunction } from '../../utils/function/function.js';
import { render, renderHttpError } from '../../render/render.js';
/**
 * Output preview from contentful or wordpress
 *
 * @param {ServerlessContext} context
 * @param {ServerlessSetup} setupServerless
 * @param {function} getData - getAllContentfulData | getAllWordPressData
 * @return {Promise<Response>} Response
 */
const Preview = async (context, setupServerless, getData) => {
    /* Params */
    const { request, next } = context;
    const { searchParams } = new URL(request.url);
    const contentType = searchParams.get('content_type');
    const id = searchParams.get('preview');
    /* Preview id and content type required */
    if (!isStringStrict(id) || !isStringStrict(contentType)) {
        return next(); // eslint-disable-line @typescript-eslint/return-await
    }
    /* Setup */
    setupServerless(context);
    /* Data params */
    const previewData = { id, contentType };
    /* Output */
    const data = await render({
        previewData,
        allData: await getData({
            previewData
        })
    });
    let html = '';
    let status = 200;
    if (isObjectStrict(data)) {
        html = data.output;
    }
    const isEmpty = html === '';
    if (isEmpty) {
        status = 404;
    }
    if (isEmpty && isFunction(renderHttpError)) {
        html = await renderHttpError({ code: status });
    }
    return new Response(html, {
        status,
        headers: {
            'Content-Type': 'text/html;charset=UTF-8'
        }
    });
};
/* Export */
export { Preview };
