/**
 * Serverless
 */
import { isStringStrict } from '../utils/string/string.js';
import { isObjectStrict } from '../utils/object/object.js';
/**
 * Directory to write serverless files to
 *
 * @type {string}
 */
let serverlessDir = 'functions';
/**
 * Serverless routes to create files for
 *
 * @type {ServerlessRoutes}
 */
let serverlessRoutes = {
    reload: []
};
/**
 * Api keys for use in serverless functions
 *
 * @type {GenericStrings}
 */
let serverlessApiKeys = {
    smtp2go: ''
};
/**
 * Actions to use in serverless functions
 *
 * @type {ServerlessActions}
 */
let serverlessActions = {};
/**
 * Set serverless options
 *
 * @param {ServerlessArgs} args
 * @param {string} [dir]
 */
const setServerless = (args, dir = 'functions') => {
    if (!isObjectStrict(args)) {
        return false;
    }
    const { actions, routes, apiKeys } = args;
    if (isObjectStrict(actions)) {
        serverlessActions = { ...actions };
    }
    if (isObjectStrict(routes)) {
        serverlessRoutes = {
            ...{ reload: [] },
            ...routes
        };
    }
    if (isObjectStrict(apiKeys)) {
        serverlessApiKeys = {
            ...{ smtp2go: '' },
            ...apiKeys
        };
    }
    if (isStringStrict(dir)) {
        serverlessDir = dir;
    }
    return true;
};
/* Exports */
export { serverlessDir, serverlessRoutes, serverlessApiKeys, serverlessActions, setServerless };
