/**
 * Store
 */
import type { Store } from './storeTypes.js';
import type { RenderAllData } from '../render/renderTypes.js';
/**
 * Directory to write store files to
 *
 * @type {string}
 */
declare let storeDir: string;
/**
 * Store options
 *
 * @type {Store}
 */
declare let store: Store;
/**
 * Update default store with user options
 *
 * @param {Store} args
 * @param {string} [dir]
 * @return {Store}
 */
declare const setStore: <T extends object>(args: T, dir?: string) => Store & T;
/**
 * Update individual store property
 *
 * @param {string} prop
 * @param {object} value
 * @param {string} [subProp]
 * @return {boolean}
 */
declare const setStoreItem: <T extends Store, K extends keyof T, V extends keyof T[K] | undefined = undefined>(prop: K, value: V extends keyof T[K] ? T[K][V] : T[K], subProp?: V) => boolean;
/**
 * Set serverless or build time data (navigations, archive meta, parents)
 *
 * @param {RenderAllData} allData
 * @param {boolean} [isServerless]
 * @return {Promise<boolean>}
 */
declare const setStoreData: (allData: RenderAllData, isServerless?: boolean) => Promise<boolean>;
/**
 * Get individual store property
 *
 * @param {string} prop
 * @return {object}
 */
declare const getStoreItem: <T extends Store, K extends keyof T>(prop: K) => T[K];
/**
 * Set and get serverless store property
 *
 * @param {string} prop
 * @return {object}
 */
declare const fetchStoreItem: <T extends Store, K extends keyof T>(prop: K) => Promise<T[K]>;
export { store, storeDir, setStore, setStoreData, fetchStoreItem, setStoreItem, getStoreItem };
