/**
 * Utils - Action
 */
import type { Actions, ActionMap, ActionReturnType } from './actionTypes.js';
/**
 * Action callbacks by name
 *
 * @type {ActionMap}
 */
declare let actions: ActionMap;
/**
 * Add action to action map
 *
 * @param {string} name
 * @param {function} action
 * @return {boolean}
 */
declare const addAction: <T extends keyof Actions>(name: T, action: Actions[T]) => boolean;
/**
 * Remove action from actions map
 *
 * @param {string} name
 * @param {function} action
 * @return {boolean}
 */
declare const removeAction: <T extends keyof Actions>(name: T, action: Actions[T]) => boolean;
/**
 * Run callback functions from actions map
 *
 * @param {string} name
 * @param {*} [args]
 * @param {boolean} [isAsync]
 * @return {*}
 */
declare const doActions: <T, V extends boolean = false>(name: string, args?: T, isAsync?: V) => ActionReturnType<V>;
/**
 * Empty actions map
 *
 * @return {void}
 */
declare const resetActions: () => void;
/**
 * Fill actions map
 *
 * @param {Actions} args
 * @return {boolean}
 */
declare const setActions: (args: Partial<Actions>) => boolean;
export { actions, addAction, removeAction, doActions, resetActions, setActions };
