/**
 * Utils - Action Types
 */
import type { GenericFunctions } from '../../global/globalTypes.js';
import type { RenderStartAction, RenderEndAction, RenderItemStartAction, RenderItemEndAction } from '../../render/renderTypes.js';
/**
 * @typedef Actions
 * @type {GenericFunctions}
 * @prop {RenderStartAction} renderStart
 * @prop {RenderEndAction} renderEnd
 * @prop {RenderItemStartAction} renderItemStart
 * @prop {RenderItemEndAction} renderItemEnd
 */
export interface Actions extends GenericFunctions {
    renderStart: RenderStartAction;
    renderEnd: RenderEndAction;
    renderItemStart: RenderItemStartAction;
    renderItemEnd: RenderItemEndAction;
}
/**
 * @typedef ActionMap
 * @type {Map.<string, Set<Function>>}
 * @prop {Set<RenderStartAction>} renderStart
 * @prop {Set<RenderEndAction>} renderEnd
 * @prop {Set<RenderItemStartAction>} renderItemStart
 * @prop {Set<RenderItemEndAction>} renderItemEnd
 */
export type ActionMap = Map<string, Set<Function>> & Map<'renderStart' | 'renderEnd' | 'renderItemStart' | 'renderItemEnd', Set<RenderStartAction | RenderEndAction | RenderItemStartAction | RenderItemEndAction>>;
/**
 * @typedef {void|Promise<void>} ActionReturnType
 */
export type ActionReturnType<V extends false | true> = V extends true ? Promise<void> : undefined;
