/**
 * Utils - Archive
 */
import type { ArchiveInfo, ArchiveTaxonomy, ArchiveLink, ArchiveLabels } from './archiveTypes.js';
import type { RenderItem } from '../../render/renderTypes.js';
/**
 * Get archive id, slug and title
 *
 * @param {string} contentType
 * @return {ArchiveInfo}
 */
declare const getArchiveInfo: (contentType: string) => ArchiveInfo;
/**
 * Get taxonomy attributes
 *
 * @param {string} contentType
 * @param {RenderItem} [pageData]
 * @return {ArchiveTaxonomy}
 */
declare const getTaxonomyInfo: (contentType: string, pageData?: RenderItem) => ArchiveTaxonomy;
/**
 * Get archive link by content type or taxonomy
 *
 * @param {string} contentType
 * @param {RenderItem} [pageData]
 * @return {ArchiveLink}
 */
declare const getArchiveLink: (contentType: string, pageData?: RenderItem) => ArchiveLink;
/**
 * Singular and plural labels by content/taxonomy type
 *
 * @param {string} contentType
 * @param {RenderItem} [pageData]
 * @return {ArchiveLabels}
 */
declare const getArchiveLabels: (contentType: string, pageData?: RenderItem) => ArchiveLabels;
export { getArchiveInfo, getTaxonomyInfo, getArchiveLink, getArchiveLabels };
