/**
 * Utils - Object
 */
/**
 * Check if value is an object
 *
 * @param {*} value
 * @return {boolean}
 */
declare const isObject: <T>(value: T) => value is object & T;
/**
 * Non-object types
 */
type NotObject<T, K> = Exclude<T, string | number | boolean | Function | Map<T, K> | Set<T> | FormData | null | undefined | unknown[] | string[] | number[] | boolean[] | Function[]>;
/**
 * Check if value is an object and not object-like (array, map, blob etc.)
 *
 * @param {*} value
 * @return {boolean}
 */
declare const isObjectStrict: <T, K>(value: T) => value is object & NotObject<T, K>;
export { isObject, isObjectStrict };
